@@ -4,7 +4,7 @@ import contextlib
 import io
 
 from pre_commit.languages import helpers
-from pre_commit.prefixed_command_runner import CalledProcessError
+from pre_commit.util import CalledProcessError
 from pre_commit.util import clean_path_on_failure
 from pre_commit.util import resource_filename
 from pre_commit.util import tarfile_open
@@ -65,7 +65,7 @@ def _install_rbenv(repo_cmd_runner, version='default'):
 def _install_ruby(environment, version):
     try:
         environment.run('rbenv download {0}'.format(version))
-    except CalledProcessError:
+    except CalledProcessError:  # pragma: no cover (usually find with download)
         # Failed to download from mirror for some reason, build it instead
         environment.run('rbenv install {0}'.format(version))
 
