@@ -1,14 +1,16 @@
 from __future__ import unicode_literals
 
 import subprocess
+import sys
 
 from pre_commit import color
+from pre_commit import five
 
 
 # TODO: smell: import side-effects
 COLS = int(
     subprocess.Popen(
-        ['tput', 'cols'], stdout=subprocess.PIPE
+        ['tput', 'cols'], stdout=subprocess.PIPE,
     ).communicate()[0] or
     # Default in the case of no terminal
     80
@@ -16,13 +18,13 @@ COLS = int(
 
 
 def get_hook_message(
-    start,
-    postfix='',
-    end_msg=None,
-    end_len=0,
-    end_color=None,
-    use_color=None,
-    cols=COLS,
+        start,
+        postfix='',
+        end_msg=None,
+        end_len=0,
+        end_color=None,
+        use_color=None,
+        cols=COLS,
 ):
     """Prints a message for running a hook.
 
@@ -70,3 +72,14 @@ def get_hook_message(
             postfix,
             color.format_color(end_msg, end_color, use_color),
         )
+
+
+def sys_stdout_write_wrapper(s, stream=sys.stdout):
+    """Python 2.6 chokes on unicode being passed to sys.stdout.write.
+
+    This is an adapter because PY2 is ok with bytes and PY3 requires text.
+    """
+    assert type(s) is five.text
+    if five.PY2:  # pragma: no cover (PY2)
+        s = s.encode('UTF-8')
+    stream.write(s)
